--- loncom/interface/portfolio.pm 2012/12/17 02:06:32 1.238
+++ loncom/interface/portfolio.pm 2013/04/11 14:59:49 1.240
@@ -1,7 +1,7 @@
# The LearningOnline Network
# portfolio browser
#
-# $Id: portfolio.pm,v 1.238 2012/12/17 02:06:32 raeburn Exp $
+# $Id: portfolio.pm,v 1.240 2013/04/11 14:59:49 bisitz Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -63,7 +63,7 @@ sub group_form_data {
return $output;
}
# receives a file name and path stub from username/userfiles/portfolio/
# returns an anchor tag consisting encoding filename and currentpath
sub make_anchor {
my ($url, $anchor_fields, $inner_text) = @_;
@@ -809,7 +809,7 @@ sub rename_confirmed {
return;
}
if ($filenewname ne $env{'form.filenewname'}) {
- $r->print(&mt("The new file name was changed from:
[_1] to [_2]",
+ $r->print(&mt("The new filename was changed from:
[_1] to [_2]",
''.&display_file('',$env{'form.filenewname'}).'',
''.&display_file('',$filenewname).''));
}
@@ -2379,12 +2379,13 @@ sub get_port_path {
sub missing_priv {
my ($r,$url,$priv) = @_;
- my $longtext = {
+ my %longtext =
+ &Apache::lonlocal::texthash(
upload => 'upload files',
delete => 'delete files',
rename => 'rename files',
setacl => 'set access controls for files',
- };
+ );
my $escpath = &HTML::Entities::encode($env{'form.currentpath'},'&<>"');
my $rtnlink = 'print(' '.&mt("in the group's group portfolio."));
$rtnlink .= &group_args()
} else {
- $r->print(&mt('in this portfolio.'));
+ $r->print(' '.&mt('in this portfolio.'));
}
$rtnlink .= '">'.&mt('Return to directory').'';
$r->print('
@@ -63,7 +63,7 @@ sub group_form_data {
return $output;
}
-# receives a file name and path stub from username/userfiles/portfolio/
+# receives a filename and path stub from username/userfiles/portfolio/
# returns an anchor tag consisting encoding filename and currentpath
sub make_anchor {
'.$rtnlink);